@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
-from flask import jsonify, request
+from flask import request
 
 from blueflask.lib.errors import not_found
 from blueflask.lib.infos import success
 
-from ....consts import API_REGISTRY
+from ....consts import API_REGISTRY, SERVICE_CODE
 from . import api
 
 
@@ -17,14 +17,14 @@ def get_service_infos_in_registry(service):
     tags:
       - Registry
     """
-    infos = API_REGISTRY.hgetall('service:{}-services'.format(service))
+    infos = API_REGISTRY.hgetall('service:{}'.format(service))
     if not infos:
-        return not_found()
+        return not_found(service_code=SERVICE_CODE)
     result = {
         key.decode('utf-8'): value.decode('utf-8')
         for key, value in infos.items()
         }
-    return jsonify(result)
+    return success(service_code=SERVICE_CODE, message=result)
 
 
 @api.route('/registry', methods=['POST', 'DELETE'])
@@ -40,14 +40,18 @@ def set_info_in_registry():
     key = 'service:{}'.format(service)
     if request.method == 'DELETE':
         if key not in [i.decode('utf-8') for i in API_REGISTRY.keys()]:
-            return not_found("Ce service n'existe pas")
+            return not_found(
+                message="Ce service n'existe pas",
+                service_code=SERVICE_CODE
+                )
         API_REGISTRY.delete(key)
     else:
         del data['service']
         address = data['address']
         del data['address']
+        API_REGISTRY.delete(key)
         API_REGISTRY.hmset(key, data)
-        API_REGISTRY.hset(key, address, data['host'])
-    return success()
+        API_REGISTRY.set(address, data['host'])
+    return success(service_code=SERVICE_CODE)
 
 # EOF
