@@ -20,14 +20,13 @@ from spyne.model.fault import Fault
 from rest_client import RestClient
 from .consts import ADDRESS
 from .consts import API_REGISTRY
-from .consts import CONFIG
 from .consts import HTTP_VERBS
+from .consts import REQUESTS_LOGS
 
-import json
+import datetime
 import re
 import xml
 
-import pika
 import requests
 import xmltodict
 
@@ -112,11 +111,11 @@ class Api(object):
               - une désignant le sous service
               - une désignant la version du service
         """
-        registry_key = 'service:{service}-services'.format(service=service)
+        registry_key = 'service:{service}'.format(service=service)
         infos = API_REGISTRY.hgetall(registry_key)
         if not infos:
             raise KeyError(
-                "Le service '{}-services' n'est pas déclaré".format(service)
+                "Le service '{}' n'est pas déclaré".format(service)
                 )
         else:
             self.service = service
@@ -137,7 +136,7 @@ class Api(object):
             self.location = (
                 'https://{host}.blueline.mg:{port}'.format(
                     host=self.host,
-                    port=self.port
+                    port=int(self.service_code[1:].replace('-', ''))
                     )
                 )
 
@@ -152,7 +151,16 @@ class Api(object):
         auth = kwargs.get('auth')
         params = kwargs.get('params')
         json_doc = kwargs.get('json')
-
+        url = self.location
+        if self.sub_service:
+            url = '{url}/{sub_service}'.format(
+                url=url,
+                sub_service=self.subservice
+                )
+        url = '{url}/api/v{version}'.format(
+            url=url,
+            version=self.version
+            )
         # avant d'appeler une ressource, on doit vérifier le token
         try:
             token = auth[0]
@@ -182,97 +190,41 @@ class Api(object):
                     },
                 'headers': headers
                 }
+            # self.record_result(method, url, result)
             return result
         elif username and not isinstance(username, bool):
             auth = (username, auth[1])
-        if not self.async:
-            url = self.location
-            if self.sub_service:
-                url = '{url}/{sub_service}'.format(
-                    url=url,
-                    sub_service=self.subservice
-                    )
-            url = '{url}/api/v{version}'.format(
-                url=url,
-                version=self.version
-                )
-            client = RestClient(url)
-            result = client.__call_url__(
-                method,
-                ressource,
-                auth=auth,
-                headers=headers,
-                params=params,
-                json=json_doc
-            )
-            return result
-        else:  # appel asynchrone
-            document = {
-                'method': method,
-                'service': self.service,
-                'version': self.version,
-                'ressource': '/{}'.format(ressource),
-                'auth': auth,
-                'params': params,
-                'headers': headers,
-                'json': json_doc
+        client = RestClient(url)
+        result = client.__call_url__(
+            method,
+            ressource,
+            auth=auth,
+            headers=headers,
+            params=params,
+            json=json_doc
+        )
+        # self.record_result(method, url, result)
+        return result
+
+    def record_result(self, method, url, result):
+        timestamp = datetime.datetime.now().strftime('%d%m%Y%H%M%S')
+        content = result['content']
+        if isinstance(content, dict):
+            infos = {
+                key: value
+                for key, value in content.items()
                 }
-            try:
-                connection = pika.BlockingConnection(
-                    pika.ConnectionParameters(
-                        host='{}.malagasy.com'.format(self.host),
-                        credentials=pika.credentials.PlainCredentials(
-                            CONFIG['RABBITMQ']['username'],
-                            CONFIG['RABBITMQ']['password']
-                            ),
-                        virtual_host='/{}'.format(self.service)
-                        )
-                    )
-            except Exception:
-                # exception de connection lancée par pika
-                # il faut que rabbitmq-server soit installé
-                # et que le vhost /{service} existe déjà
-                result = {
-                    'status': 500,
-                    'content': {
-                        'code': self.service_code+'-5000',
-                        'error': 'erreur interne',
-                        'message': (
-                            "la file d'attente de l'API n'est pas prête"
-                            ),
-                        'status': 500
-                        },
-                    'headers': kwargs.get('headers', {})
-                    }
-                return result
-            else:
-                channel = connection.channel()
-                channel.exchange_declare(
-                    exchange='async_requests',
-                    exchange_type='topic'
-                    )
-                # déclaration idempotente: pas grave si l'exchange existe déjà
-                channel.basic_publish(
-                    exchange='async_requests',
-                    routing_key='{method}.{service}'.format(
-                        method=method,
-                        service=self.service
-                        ),
-                    body=json.dumps(document),
-                    properties=pika.BasicProperties(delivery_mode=2)
-                    )
-                connection.close()
-                result = {
-                    'status': 200,
-                    'content': {
-                        'code': self.service_code+'-200',
-                        'info': 'requête acceptée',
-                        'message': 'la requête a été bien acceptée',
-                        'status': 200
-                        },
-                    'headers': kwargs.get('headers', {})
-                    }
-                return result
+        else:
+            infos = {'message': content}
+        infos['request-method'] = method
+        infos['request-url'] = url
+        key = 'request:{service}:{request_id}:{timestamp}'.format(
+            service=self.service,
+            request_id=result['headers']['X-Request-Id'],
+            timestamp=timestamp
+            )
+        REQUESTS_LOGS.hmset(key, infos)
+        REQUESTS_LOGS.expire(key, 2678400)
 
 
 class SoapPayload(object):
